@@ -45,19 +45,10 @@
 #include <atalk/logger.h>
 #include <stdio.h>
 #include <string.h>
-
-#ifdef HAVE_NETDB_H
 #include <netdb.h>
-#endif /* HAVE_NETDB_H */
 
 #include <fcntl.h>
-
-#ifdef HAVE_TERMIOS_H
 #include <termios.h>
-#endif /* HAVE_TERMIOS_H */
-#ifdef HAVE_SYS_TERMIOS_H
-#include <termios.h>
-#endif /* HAVE_SYS_TERMIOS_H */
 
 #define	TL_OK		'\0'
 #define TL_EOF		'\1'
