@@ -200,7 +200,7 @@ static void as_timer(int sig _U_)
 		iface->i_time++;
 	    } else {
 		iface->i_flags |= IFACE_NOROUTER;
-		if ((iface->i_flags & IFACE_ISROUTER)) {
+		if (iface->i_flags & IFACE_ISROUTER) {
 		    if (( iface->i_flags & IFACE_SEED ) == 0 ) {
 			/*
 			 * No seed info, and we've got multiple interfaces.
@@ -288,6 +288,10 @@ static void as_timer(int sig _U_)
 	    end = packet + sizeof( packet );
 
 	    sat = gate->g_sat;
+	    if (zap == NULL) {
+			LOG(log_error, logtype_atalkd, "as_timer: No ZIP port available for interface %s", iface->i_name);
+			continue;
+	    }
 	    sat.sat_port = zap->ap_port;
 
 	    /*
@@ -482,13 +486,17 @@ static void as_timer(int sig _U_)
 	 * Send RTMP broadcasts if we have multiple interfaces or our
 	 * interface is configured as a router.
 	 */
-	if ((iface->i_flags & IFACE_ISROUTER)) {
+	if (iface->i_flags & IFACE_ISROUTER) {
 #ifdef BSD4_4
 	    sat.sat_len = sizeof( struct sockaddr_at );
 #endif /* BSD4_4 */
 	    sat.sat_family = AF_APPLETALK;
 	    sat.sat_addr.s_net = ATADDR_ANYNET;
 	    sat.sat_addr.s_node = ATADDR_BCAST;
+		if (rap == NULL) {
+			LOG(log_error, logtype_atalkd, "as_timer: No RTMP port available for interface %s", iface->i_name);
+			continue;
+		}
 	    sat.sat_port = rap->ap_port;
 
 	    data = packet;
@@ -675,12 +683,12 @@ as_debug(int sig _U_)
     struct gate		*gate;
     struct rtmptab	*rt;
     FILE		*rtmpdebug;
+    char path_atalkdebug[MAXPATHLEN + 1];
 
-    if (_PATH_ATALKDEBUG != NULL) {
-        rtmpdebug = fopen(_PATH_ATALKDEBUG, "w");
-        if (rtmpdebug == NULL) {
-            LOG(log_error, logtype_atalkd, "rtmp: %s", strerror(errno));
-        }
+    snprintf(path_atalkdebug, sizeof(path_atalkdebug)-1, "%s/atalkd.%u.debug", tmpdir(), getpid());
+    rtmpdebug = fopen(path_atalkdebug, "w");
+    if (rtmpdebug == NULL) {
+        LOG(log_error, logtype_atalkd, "rtmp: %s", strerror(errno));
     }
 
 	if (rtmpdebug) {
@@ -1353,21 +1361,21 @@ int ifconfig( const char *iname, unsigned long cmd, struct sockaddr_at *sa)
     int			s;
 
     memset(&ifr, 0, sizeof(ifr));
-    strcpy( ifr.ifr_name, iname );
+    strlcpy(ifr.ifr_name, iname, sizeof(ifr.ifr_name));
     ifr.ifr_addr = *(struct sockaddr *)sa;
 
     if (( s = socket( AF_APPLETALK, SOCK_DGRAM, 0 )) < 0 ) {
-	return( 1 );
+	return 1;
     }
     if ( ioctl( s, cmd, &ifr ) < 0 ) {
 	close(s);
-	return( 1 );
+	return 1;
     }
     close( s );
     if ( cmd == SIOCGIFADDR ) {
 	*(struct sockaddr *)sa = ifr.ifr_addr;
     }
-    return( 0 );
+    return 0;
 }
 
 void dumpconfig( struct interface *iface)
