@@ -12,6 +12,9 @@ int PassCount = 0;
 int FailCount = 0;
 int SkipCount = 0;
 int NotTestedCount = 0;
+char FailedTests[1024][256] = {{0}};
+char NotTestedTests[1024][256] = {{0}};
+char SkippedTests[1024][256] = {{0}};
 
 DSI *Dsi;
 
@@ -20,7 +23,7 @@ char Data[300000] = "";
 char    *Server = "localhost";
 char    *Server2;
 int     Proto = 0;
-int     Port = 548;
+int     Port = DSI_AFPOVERTCP_PORT;
 char    *Password = "";
 char    *Vol = "";
 char    *User;
@@ -45,7 +48,6 @@ DSI *dsi;
         	test_nottested();
 	    	exit(ExitCode);
         }
-     	dsi->protocol = DSI_TCPIP;
 	    dsi->socket = sock;
     }
 }
@@ -298,6 +300,10 @@ int main( int ac, char **av )
 {
 int cc;
 
+    if (ac == 1) {
+        usage(av[0]);
+    }
+
     while (( cc = getopt( ac, av, "1234567CmVvh:p:u:w:" )) != EOF ) {
         switch ( cc ) {
         case '1':
